==> cfengine-3.5.0b1.tar.gz: cfengine-3.5.0b1/libpromises/crypto.h <==
/*
   Copyright (C) Cfengine AS

   This file is part of Cfengine 3 - written and maintained by Cfengine AS.

   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
   Free Software Foundation; version 3.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA

  To the extent this program is licensed as part of the Enterprise
  versions of Cfengine, the applicable Commerical Open Source License
  (COSL) may apply to this file if you as a licensee so wish it. See
  included file COSL.txt.
*/

#ifndef CFENGINE_CRYPTO_H
#define CFENGINE_CRYPTO_H

#include "platform.h"

void CryptoInitialize(void);

void DebugBinOut(char *buffer, int len, char *com);
bool LoadSecretKeys(void);
int EncryptString(char type, char *in, char *out, unsigned char *key, int len);
int DecryptString(char type, char *in, char *out, unsigned char *key, int len);
RSA *HavePublicKey(char *username, char *ipaddress, char *digest);
RSA *HavePublicKeyByIP(char *username, char *ipaddress);
void SavePublicKey(char *username, char *ipaddress, char *digest, RSA *key);

const char *PublicKeyFile(void);
const char *PrivateKeyFile(void);

#endif

==> cfengine-3.5.1.tar.gz: cfengine-3.5.1/libpromises/crypto.h <==
/*
   Copyright (C) CFEngine AS

   This file is part of CFEngine 3 - written and maintained by CFEngine AS.

   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
   Free Software Foundation; version 3.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA

  To the extent this program is licensed as part of the Enterprise
  versions of CFEngine, the applicable Commerical Open Source License
  (COSL) may apply to this file if you as a licensee so wish it. See
  included file COSL.txt.
*/

#ifndef CFENGINE_CRYPTO_H
#define CFENGINE_CRYPTO_H

#include "platform.h"

void CryptoInitialize(void);
void CryptoDeInitialize(void);

void DebugBinOut(char *buffer, int len, char *com);
bool LoadSecretKeys(const char *policy_server);
int EncryptString(char type, char *in, char *out, unsigned char *key, int len);
int DecryptString(char type, char *in, char *out, unsigned char *key, int len);
RSA *HavePublicKey(const char *username, const char *ipaddress, const char *digest);
RSA *HavePublicKeyByIP(const char *username, const char *ipaddress);
void SavePublicKey(const char *username, const char *digest, const RSA *key);

const char *PublicKeyFile(const char *workdir);
const char *PrivateKeyFile(const char *workdir);

#endif
